@@ -98,17 +98,21 @@ class JobsDB(SqliteDB):
             commandname = command.split(" ",1)[0]
             white_list = listify(white_list)
             if not commandname.lower() in white_list:
-                command = None
+                command = ""
                 params["pid"] = -1
                 params["status"] = "error"
+                params["progress"] = 100
                 params["starttime"] = ""
-                res = {"success": False, "exception": "Command not enabled!".format(**params)}
+                params["description"] = "Command not enabled!"
+                # print("{description}".format(**params))
             if "&" in command:
-                command = None
+                command = ""
                 params["pid"] = -1
                 params["status"] = "error"
+                params["progress"] = 100
                 params["starttime"] = ""
-                res = {"success": False, "exception": "Command catenation not allowed!".format(**params)}
+                params["description"] = "Command catenation not allowed!"
+                # print("{description}".format(**params))
         # --------------------------------------------------------------------------------------------------------------
         if command:
             try:
@@ -118,19 +122,20 @@ class JobsDB(SqliteDB):
                 params["pid"] = p.pid
                 params["starttime"] = strftime('%Y-%m-%d %H:%M:%S', None)
                 params["status"] = "running"
-                res = {"success": True, "data": "process started"}
+                params["progress"] = 0
             except Exception as ex:
                 params["pid"] = -1
                 params["status"] = "error"
+                params["progress"] = 100
                 params["starttime"] = ""
-                res = {"success": False, "exception": "unable to start process"}
         else:
             params["pid"] = -1
             params["status"] = "error"
+            params["progress"] = 100
             params["starttime"] = ""
-            res = {"success": False, "exception": "unable to find process with jobid={jid}".format(**params)}
 
-        sql = """UPDATE [jobs] SET status='{status}', pid='{pid}', progress=0, starttime='{starttime}' WHERE jid='{jid}';"""
+
+        sql = """UPDATE [jobs] SET status='{status}', pid='{pid}', progress={progress}, starttime='{starttime}' WHERE jid='{jid}';"""
         self.execute(sql, params)
 
     def ProcessQueue(self, parallelism = -1, max_load = 70, white_list = "", verbose = False):
@@ -148,7 +153,7 @@ class JobsDB(SqliteDB):
                 outputmode="scalar", verbose=verbose)
             cpu_load = psutil.cpu_percent(interval=1)
             if n < parallelism or cpu_load < max_load:
-                self.executeJob(job["jid"], filter)
+                self.executeJob(job["jid"], white_list)
 
     def ProcessQueueForever(self, parallelism = -1, max_load = 70, interval = 3, white_list = "", verbose=False):
         """
